@@ -1,17 +1,17 @@
 package Catalyst::Model::DBIC;
 
 use strict;
-use base 'Catalyst::Base';
+use base 'Catalyst::Model';
 use NEXT;
 use DBIx::Class::Loader;
 
-our $VERSION = '0.12';
+our $VERSION = '0.14';
 
 __PACKAGE__->mk_accessors('loader');
 
 =head1 NAME
 
-Catalyst::Model::DBIC - DBIC Model Class
+Catalyst::Model::DBIC - (DEPRECATED) DBIC Model Class
 
 =head1 SYNOPSIS
 
@@ -37,6 +37,12 @@ Catalyst::Model::DBIC - DBIC Model Class
 
     MyApp::Model::DBIC::Table->search(...);
 
+=head1 DEPRECATION NOTICE
+
+This module has been deprecated in favor of the schema-based
+L<Catalyst::Model::DBIC::Schema>. This module should only be considered
+as a temporary measure if you are porting from L<Catalyst::Model::CDBI>.
+
 =head1 DESCRIPTION
 
 This is the C<DBIx::Class> model class. It's built on top of 
@@ -53,8 +59,8 @@ Initializes DBIx::Class::Loader and loads classes using the class config.
 =cut
 
 sub new {
-    my ( $self, $c ) = @_;
-    $self = $self->NEXT::new($c);
+    my ( $self, $c, $config ) = @_;
+    $self = $self->NEXT::new($c, $config);
     $self->{namespace}               ||= ref $self;
     $self->{additional_base_classes} ||= ();
     eval { $self->loader( DBIx::Class::Loader->new(%$self) ) };
@@ -79,7 +85,7 @@ sub table { shift->loader->find_class(shift) }
 
 =head1 SEE ALSO
 
-L<Catalyst>, L<DBIx::Class> L<DBIx::Class::Loader>
+L<Catalyst>, L<DBIx::Class> L<Catalyst::Model::DBIC::Schema>
 
 =head1 AUTHOR
 
